@@ -53,3 +53,27 @@
   attr(x, "tensor_term_order") <- tensor_term_order
   x
 }
+
+#' @export
+#' @importFrom rlang has_name .data
+#' @importFrom dplyr filter reframe pull
+`[.parametric_effects` <- function(x, i, j, drop = FALSE) {
+  cls <- class(x)
+  f_levels <- attr(x, "factor_levels")
+  class(x) <- class(x)[-c(1:2)]
+  x <- NextMethod()
+  class(x) <- cls
+  if (has_name(x, ".type")) {
+    f_names <- x |>
+      filter(.data$.type %in% c("factor", "ordered")) |>
+      reframe(f = unique(.data$.term)) |>
+      pull("f")
+    if (!is.na(f_levels)) {
+      f_levels <- f_levels[f_names]
+    }
+  } else {
+    f_levels <- NA
+  }
+  attr(x, "factor_levels") <- f_levels
+  x
+}
